pub struct CommandReport {
pub command_id: Uuid,
pub command: String,
pub flags: Vec<String>,
pub started_at: DateTime<Utc>,
pub finished_at: DateTime<Utc>,
pub exit_code: i32,
pub truncated: bool,
}Expand description
Cooperative client telemetry, not proof that these were all browser actions. Retrying this report must never execute the command again. Browser output remains on the client and has no field in this telemetry protocol.
Fields
command_id: Uuidcommand: Stringflags: Vec<String>started_at: DateTime<Utc>finished_at: DateTime<Utc>exit_code: i32truncated: boolTrait Implementations
Sourceimpl Clone for CommandReport
impl Clone for CommandReport
Sourcefn clone(&self) -> CommandReport
fn clone(&self) -> CommandReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandReport
impl Debug for CommandReport
Sourceimpl<'de> Deserialize<'de> for CommandReport
impl<'de> Deserialize<'de> for CommandReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CommandReport
Sourceimpl PartialEq for CommandReport
impl PartialEq for CommandReport
Sourceimpl Serialize for CommandReport
impl Serialize for CommandReport
impl StructuralPartialEq for CommandReport
Sourceimpl Validate for CommandReport
impl Validate for CommandReport